<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sk">
<context>
    <name>EllipseDD</name>
    <message>
        <location filename="../EllipseDD.ui" line="+17"/>
        <location filename="../EllipseDDDialog.ui" line="+19"/>
        <source>X Diameter:</source>
        <translation>Dĺžka v osi X:</translation>
    </message>
    <message>
        <location line="+23"/>
        <location filename="../EllipseDDDialog.ui" line="+80"/>
        <source>Y Diameter:</source>
        <translation>Dĺžka v osi Y:</translation>
    </message>
    <message>
        <location line="+30"/>
        <location filename="../EllipseDDDialog.ui" line="-23"/>
        <source>Angle:</source>
        <translation>Uhol:</translation>
    </message>
    <message>
        <location line="+36"/>
        <source>Reference Point:</source>
        <translation>Referenčný bod:</translation>
    </message>
    <message>
        <location filename="../EllipseDDInit.js" line="+2"/>
        <source>Ellipse with &amp;Diameters</source>
        <translation>Elipsa z &amp;Dĺžok</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Draw ellipse with position and diameters</source>
        <translation>Nakresliť elipsu so zadanými rozmermi a určením polohy</translation>
    </message>
</context>
</TS>
